# R Script File for Section 4: Trees in R

# Categorical Outcome

Stevens = read.csv("Stevens.csv")
str(Stevens)

install.packages("rpart")
library(rpart)
install.packages("rpart.plot")
library(rpart.plot)
install.packages("randomForest")
library(randomForest)

set.seed(100)
spl = sample.split(Stevens$Reverse, SplitRatio = 0.70)
StevensTrain = subset(Stevens, spl==TRUE)
StevensTest = subset(Stevens, spl==FALSE)

# CART

StevensTree = rpart(Reverse ~ Circuit + Issue + Petitioner + Respondent + LowerCourt + Unconst, method="class", data=StevensTrain, minbucket=25)

prp(StevensTree)

set.seed(100)
spl = sample.split(StevensTrain$Reverse, SplitRatio = 0.5)
StevensValidateTrain = subset(StevensTrain, spl == TRUE)
StevensValidateTest = subset(StevensTrain, spl == FALSE)

StevensTree1 = rpart(Reverse ~ Circuit + Issue + Petitioner + Respondent + LowerCourt + Unconst, method = "class", data = StevensValidateTrain, minbucket=5)
StevensTree2 = rpart(Reverse ~ Circuit + Issue + Petitioner + Respondent + LowerCourt + Unconst, method = "class", data = StevensValidateTrain, minbucket=15)
StevensTree3 = rpart(Reverse ~ Circuit + Issue + Petitioner + Respondent + LowerCourt + Unconst, method = "class", data = StevensValidateTrain, minbucket=25)

StevensPredict1 = predict(StevensTree1, newdata=StevensValidateTest, type="class")
StevensPredict2 = predict(StevensTree2, newdata=StevensValidateTest, type="class")
StevensPredict3 = predict(StevensTree3, newdata=StevensValidateTest, type="class")

table(StevensValidateTest$Reverse, StevensPredict1)
table(StevensValidateTest$Reverse, StevensPredict2)
table(StevensValidateTest$Reverse, StevensPredict3)

StevensTreeFinal = rpart(Reverse ~ Circuit + Issue + Petitioner + Respondent + LowerCourt + Unconst, method="class", data=StevensTrain, minbucket=25)
StevensPredictTest = predict(StevensTreeFinal, newdata=StevensTest, type="class")
table(StevensTest$Reverse, StevensPredictTest)


# Random Forest

StevensTrain$Reverse = as.factor(StevensTrain$Reverse)
StevensTest$Reverse = as.factor(StevensTest$Reverse)

StevensForest = randomForest(Reverse ~ Circuit + Issue + Petitioner + Respondent + LowerCourt + Unconst, data = StevensTrain, ntree=200, nodesize=15)

StevensPredictForest = predict(StevensForest, newdata=StevensTest)
table(StevensTest$Reverse, StevensPredictForest)


# Continuous Outcomes

WineTrain = read.csv("Wine.csv")
WineTest = read.csv("WineTest.csv")

# CART

WineTree = rpart(Price ~ WinterRain + AGST + HarvestRain + Age, data = WineTrain, minbucket = 3)

prp(WineTree)

WinePredictTree = predict(WineTree, newdata = WineTest)
SSE = sum((WineTest$Price - WinePredictTree)^2)
SST = sum((WineTest$Price - mean(Wine$Price))^2)
1 - SSE/SST

# Random Forest

WineForest = randomForest(Price ~ WinterRain + AGST + HarvestRain + Age, data = WineTrain, ntree = 200, nodesize = 3)
WinePredictForest = predict(WineForest, newdata = WineTest)
SSE = sum((WineTest$Price - WinePredictForest)^2)
SST = sum((WineTest$Price - mean(Wine$Price))^2)
1 - SSE/SST
